(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/forms'], factory) :
	(factory((global['trumbowyg-ngx'] = {}),global.ng.core,global.ng.forms));
}(this, (function (exports,core,forms) { 'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0
THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.
See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */
/* global Reflect, Promise */
var extendStatics = Object.setPrototypeOf ||
    ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
    function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
function __extends(d, b) {
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var EditorBase = /** @class */ (function () {
    function EditorBase(editorControl, _config) {
        this.editorControl = editorControl;
        this._config = _config;
        this.propagateChange = function (_) {
        };
        this.propagateTouched = function () {
        };
        editorControl.valueAccessor = this;
    }
    EditorBase.prototype.ngOnInit = function () {
        var control = this.editorControl.control;
        control.setValidators(control.validator);
        control.updateValueAndValidity();
    };
    EditorBase.prototype.ngAfterViewInit = function () {
        var _this = this;
        $(this._editor.nativeElement).trumbowyg(Object.assign({}, this._config, this.options)).on('tbwinit', function () {
            $(_this._editor.nativeElement).trumbowyg(_this._disabled ? 'disable' : 'enable');
            _this.setContent(_this._initValue);
        }).on('tbwchange', function () {
            _this.propagateChange(_this.getContent());
        }).on('tbwblur', function () {
            _this.propagateTouched();
        });
    };
    EditorBase.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    EditorBase.prototype.registerOnTouched = function (fn) {
        this.propagateTouched = fn;
    };
    EditorBase.prototype.writeValue = function (value) {
        this._initValue = value;
        if (this._editor && this._editor.nativeElement) {
            this.setContent(value);
        }
    };
    EditorBase.prototype.setDisabledState = function (disabled) {
        this._disabled = disabled;
    };
    EditorBase.prototype.ngOnDestroy = function () {
        $(this._editor.nativeElement).trumbowyg('destroy');
    };
    EditorBase.prototype.setContent = function (content) {
        $(this._editor.nativeElement).trumbowyg('html', content);
    };
    EditorBase.prototype.getContent = function () {
        return $(this._editor.nativeElement).trumbowyg('html');
    };
    return EditorBase;
}());
var TRUMBOWYG_OPTIONS = new core.InjectionToken('Trumbowyg options');
var EditorDirective = /** @class */ (function (_super) {
    __extends(EditorDirective, _super);
    function EditorDirective(editorControl, _config, _editor) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        _this._editor = _editor;
        return _this;
    }
    return EditorDirective;
}(EditorBase));
EditorDirective.decorators = [
    { type: core.Directive, args: [{
                selector: '[trumbowygNgxEditor]'
            },] },
];
EditorDirective.ctorParameters = function () { return [
    { type: forms.NgControl, },
    { type: undefined, decorators: [{ type: core.Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: core.Optional },] },
    { type: core.ElementRef, },
]; };
EditorDirective.propDecorators = {
    "options": [{ type: core.Input },],
    "placeholder": [{ type: core.Input },],
};
var EditorComponent = /** @class */ (function (_super) {
    __extends(EditorComponent, _super);
    function EditorComponent(editorControl, _config) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        return _this;
    }
    return EditorComponent;
}(EditorBase));
EditorComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'trumbowyg-ngx-editor',
                template: "<textarea #editor [placeholder]=\"placeholder ? placeholder : ''\"></textarea>\n",
                styles: [""],
                changeDetection: core.ChangeDetectionStrategy.OnPush,
                encapsulation: core.ViewEncapsulation.None
            },] },
];
EditorComponent.ctorParameters = function () { return [
    { type: forms.NgControl, },
    { type: undefined, decorators: [{ type: core.Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: core.Optional },] },
]; };
EditorComponent.propDecorators = {
    "options": [{ type: core.Input },],
    "placeholder": [{ type: core.Input },],
    "_editor": [{ type: core.ViewChild, args: ['editor',] },],
};
var TrumbowygNgxModule = /** @class */ (function () {
    function TrumbowygNgxModule() {
    }
    TrumbowygNgxModule.withConfig = function (options) {
        return {
            ngModule: TrumbowygNgxModule,
            providers: [
                { provide: TRUMBOWYG_OPTIONS, useValue: options }
            ]
        };
    };
    return TrumbowygNgxModule;
}());
TrumbowygNgxModule.decorators = [
    { type: core.NgModule, args: [{
                declarations: [
                    EditorComponent,
                    EditorDirective
                ],
                exports: [
                    EditorComponent,
                    EditorDirective
                ]
            },] },
];
TrumbowygNgxModule.ctorParameters = function () { return []; };

exports.TrumbowygNgxModule = TrumbowygNgxModule;
exports.ɵa = EditorComponent;
exports.ɵd = TRUMBOWYG_OPTIONS;
exports.ɵe = EditorDirective;
exports.ɵb = EditorBase;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=trumbowyg-ngx.umd.js.map
