import { __extends } from 'tslib';
import { InjectionToken, Directive, ElementRef, Inject, Input, Optional, ChangeDetectionStrategy, Component, ViewChild, ViewEncapsulation, NgModule } from '@angular/core';
import { NgControl } from '@angular/forms';

var EditorBase = /** @class */ (function () {
    function EditorBase(editorControl, _config) {
        this.editorControl = editorControl;
        this._config = _config;
        this.propagateChange = function (_) {
        };
        this.propagateTouched = function () {
        };
        editorControl.valueAccessor = this;
    }
    EditorBase.prototype.ngOnInit = function () {
        var control = this.editorControl.control;
        control.setValidators(control.validator);
        control.updateValueAndValidity();
    };
    EditorBase.prototype.ngAfterViewInit = function () {
        var _this = this;
        $(this._editor.nativeElement).trumbowyg(Object.assign({}, this._config, this.options)).on('tbwinit', function () {
            $(_this._editor.nativeElement).trumbowyg(_this._disabled ? 'disable' : 'enable');
            _this.setContent(_this._initValue);
        }).on('tbwchange', function () {
            _this.propagateChange(_this.getContent());
        }).on('tbwblur', function () {
            _this.propagateTouched();
        });
    };
    EditorBase.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    EditorBase.prototype.registerOnTouched = function (fn) {
        this.propagateTouched = fn;
    };
    EditorBase.prototype.writeValue = function (value) {
        this._initValue = value;
        if (this._editor && this._editor.nativeElement) {
            this.setContent(value);
        }
    };
    EditorBase.prototype.setDisabledState = function (disabled) {
        this._disabled = disabled;
    };
    EditorBase.prototype.ngOnDestroy = function () {
        $(this._editor.nativeElement).trumbowyg('destroy');
    };
    EditorBase.prototype.setContent = function (content) {
        $(this._editor.nativeElement).trumbowyg('html', content);
    };
    EditorBase.prototype.getContent = function () {
        return $(this._editor.nativeElement).trumbowyg('html');
    };
    return EditorBase;
}());
var TRUMBOWYG_OPTIONS = new InjectionToken('Trumbowyg options');
var EditorDirective = /** @class */ (function (_super) {
    __extends(EditorDirective, _super);
    function EditorDirective(editorControl, _config, _editor) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        _this._editor = _editor;
        return _this;
    }
    return EditorDirective;
}(EditorBase));
EditorDirective.decorators = [
    { type: Directive, args: [{
                selector: '[trumbowygNgxEditor]'
            },] },
];
EditorDirective.ctorParameters = function () { return [
    { type: NgControl, },
    { type: undefined, decorators: [{ type: Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: Optional },] },
    { type: ElementRef, },
]; };
EditorDirective.propDecorators = {
    "options": [{ type: Input },],
    "placeholder": [{ type: Input },],
};
var EditorComponent = /** @class */ (function (_super) {
    __extends(EditorComponent, _super);
    function EditorComponent(editorControl, _config) {
        var _this = _super.call(this, editorControl, _config) || this;
        _this.editorControl = editorControl;
        _this._config = _config;
        return _this;
    }
    return EditorComponent;
}(EditorBase));
EditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'trumbowyg-ngx-editor',
                template: "<textarea #editor [placeholder]=\"placeholder ? placeholder : ''\"></textarea>\n",
                styles: [""],
                changeDetection: ChangeDetectionStrategy.OnPush,
                encapsulation: ViewEncapsulation.None
            },] },
];
EditorComponent.ctorParameters = function () { return [
    { type: NgControl, },
    { type: undefined, decorators: [{ type: Inject, args: [TRUMBOWYG_OPTIONS,] }, { type: Optional },] },
]; };
EditorComponent.propDecorators = {
    "options": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "_editor": [{ type: ViewChild, args: ['editor',] },],
};
var TrumbowygNgxModule = /** @class */ (function () {
    function TrumbowygNgxModule() {
    }
    TrumbowygNgxModule.withConfig = function (options) {
        return {
            ngModule: TrumbowygNgxModule,
            providers: [
                { provide: TRUMBOWYG_OPTIONS, useValue: options }
            ]
        };
    };
    return TrumbowygNgxModule;
}());
TrumbowygNgxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    EditorComponent,
                    EditorDirective
                ],
                exports: [
                    EditorComponent,
                    EditorDirective
                ]
            },] },
];
TrumbowygNgxModule.ctorParameters = function () { return []; };

export { TrumbowygNgxModule, EditorComponent as ɵa, TRUMBOWYG_OPTIONS as ɵd, EditorDirective as ɵe, EditorBase as ɵb };
//# sourceMappingURL=trumbowyg-ngx.js.map
